define({ root:

//begin v1.x content
{
	"field-thu-narrow-relative+0": "this Thursday",
	"field-thu-narrow-relative+1": "next Thursday",
	"field-dayOfYear-narrow@localeAlias1594": {
		"bundle": "",
		"target": "field-dayOfYear-short"
	},
	"field-sun-narrow-relative+0": "this Sunday",
	"field-dayOfYear-narrow@localeAlias1595": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-sun-narrow-relative+1": "next Sunday",
	"months-format-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dayPeriods-standAlone-abbr-pm": "PM",
	"dateFormatItem-Hms": "HH:mm:ss",
	"field-fri-narrow-relative+0": "this Friday",
	"eraNarrow": [
		"Taika (645–650)",
		"Hakuchi (650–671)",
		"Hakuhō (672–686)",
		"Shuchō (686–701)",
		"Taihō (701–704)",
		"Keiun (704–708)",
		"Wadō (708–715)",
		"Reiki (715–717)",
		"Yōrō (717–724)",
		"Jinki (724–729)",
		"Tenpyō (729–749)",
		"Tenpyō-kampō (749–749)",
		"Tenpyō-shōhō (749–757)",
		"Tenpyō-hōji (757–765)",
		"Tenpyō-jingo (765–767)",
		"Jingo-keiun (767–770)",
		"Hōki (770–780)",
		"Ten-ō (781–782)",
		"Enryaku (782–806)",
		"Daidō (806–810)",
		"Kōnin (810–824)",
		"Tenchō (824–834)",
		"Jōwa (834–848)",
		"Kajō (848–851)",
		"Ninju (851–854)",
		"Saikō (854–857)",
		"Ten-an (857–859)",
		"Jōgan (859–877)",
		"Gangyō (877–885)",
		"Ninna (885–889)",
		"Kanpyō (889–898)",
		"Shōtai (898–901)",
		"Engi (901–923)",
		"Enchō (923–931)",
		"Jōhei (931–938)",
		"Tengyō (938–947)",
		"Tenryaku (947–957)",
		"Tentoku (957–961)",
		"Ōwa (961–964)",
		"Kōhō (964–968)",
		"Anna (968–970)",
		"Tenroku (970–973)",
		"Ten’en (973–976)",
		"Jōgen (976–978)",
		"Tengen (978–983)",
		"Eikan (983–985)",
		"Kanna (985–987)",
		"Eien (987–989)",
		"Eiso (989–990)",
		"Shōryaku (990–995)",
		"Chōtoku (995–999)",
		"Chōhō (999–1004)",
		"Kankō (1004–1012)",
		"Chōwa (1012–1017)",
		"Kannin (1017–1021)",
		"Jian (1021–1024)",
		"Manju (1024–1028)",
		"Chōgen (1028–1037)",
		"Chōryaku (1037–1040)",
		"Chōkyū (1040–1044)",
		"Kantoku (1044–1046)",
		"Eishō (1046–1053)",
		"Tengi (1053–1058)",
		"Kōhei (1058–1065)",
		"Jiryaku (1065–1069)",
		"Enkyū (1069–1074)",
		"Shōho (1074–1077)",
		"Shōryaku (1077–1081)",
		"Eihō (1081–1084)",
		"Ōtoku (1084–1087)",
		"Kanji (1087–1094)",
		"Kahō (1094–1096)",
		"Eichō (1096–1097)",
		"Jōtoku (1097–1099)",
		"Kōwa (1099–1104)",
		"Chōji (1104–1106)",
		"Kashō (1106–1108)",
		"Tennin (1108–1110)",
		"Ten-ei (1110–1113)",
		"Eikyū (1113–1118)",
		"Gen’ei (1118–1120)",
		"Hōan (1120–1124)",
		"Tenji (1124–1126)",
		"Daiji (1126–1131)",
		"Tenshō (1131–1132)",
		"Chōshō (1132–1135)",
		"Hōen (1135–1141)",
		"Eiji (1141–1142)",
		"Kōji (1142–1144)",
		"Ten’yō (1144–1145)",
		"Kyūan (1145–1151)",
		"Ninpei (1151–1154)",
		"Kyūju (1154–1156)",
		"Hōgen (1156–1159)",
		"Heiji (1159–1160)",
		"Eiryaku (1160–1161)",
		"Ōho (1161–1163)",
		"Chōkan (1163–1165)",
		"Eiman (1165–1166)",
		"Nin’an (1166–1169)",
		"Kaō (1169–1171)",
		"Shōan (1171–1175)",
		"Angen (1175–1177)",
		"Jishō (1177–1181)",
		"Yōwa (1181–1182)",
		"Juei (1182–1184)",
		"Genryaku (1184–1185)",
		"Bunji (1185–1190)",
		"Kenkyū (1190–1199)",
		"Shōji (1199–1201)",
		"Kennin (1201–1204)",
		"Genkyū (1204–1206)",
		"Ken’ei (1206–1207)",
		"Jōgen (1207–1211)",
		"Kenryaku (1211–1213)",
		"Kenpō (1213–1219)",
		"Jōkyū (1219–1222)",
		"Jōō (1222–1224)",
		"Gennin (1224–1225)",
		"Karoku (1225–1227)",
		"Antei (1227–1229)",
		"Kanki (1229–1232)",
		"Jōei (1232–1233)",
		"Tenpuku (1233–1234)",
		"Bunryaku (1234–1235)",
		"Katei (1235–1238)",
		"Ryakunin (1238–1239)",
		"En’ō (1239–1240)",
		"Ninji (1240–1243)",
		"Kangen (1243–1247)",
		"Hōji (1247–1249)",
		"Kenchō (1249–1256)",
		"Kōgen (1256–1257)",
		"Shōka (1257–1259)",
		"Shōgen (1259–1260)",
		"Bun’ō (1260–1261)",
		"Kōchō (1261–1264)",
		"Bun’ei (1264–1275)",
		"Kenji (1275–1278)",
		"Kōan (1278–1288)",
		"Shōō (1288–1293)",
		"Einin (1293–1299)",
		"Shōan (1299–1302)",
		"Kengen (1302–1303)",
		"Kagen (1303–1306)",
		"Tokuji (1306–1308)",
		"Enkyō (1308–1311)",
		"Ōchō (1311–1312)",
		"Shōwa (1312–1317)",
		"Bunpō (1317–1319)",
		"Genō (1319–1321)",
		"Genkō (1321–1324)",
		"Shōchū (1324–1326)",
		"Karyaku (1326–1329)",
		"Gentoku (1329–1331)",
		"Genkō (1331–1334)",
		"Kenmu (1334–1336)",
		"Engen (1336–1340)",
		"Kōkoku (1340–1346)",
		"Shōhei (1346–1370)",
		"Kentoku (1370–1372)",
		"Bunchū (1372–1375)",
		"Tenju (1375–1379)",
		"Kōryaku (1379–1381)",
		"Kōwa (1381–1384)",
		"Genchū (1384–1392)",
		"Meitoku (1384–1387)",
		"Kakei (1387–1389)",
		"Kōō (1389–1390)",
		"Meitoku (1390–1394)",
		"Ōei (1394–1428)",
		"Shōchō (1428–1429)",
		"Eikyō (1429–1441)",
		"Kakitsu (1441–1444)",
		"Bun’an (1444–1449)",
		"Hōtoku (1449–1452)",
		"Kyōtoku (1452–1455)",
		"Kōshō (1455–1457)",
		"Chōroku (1457–1460)",
		"Kanshō (1460–1466)",
		"Bunshō (1466–1467)",
		"Ōnin (1467–1469)",
		"Bunmei (1469–1487)",
		"Chōkyō (1487–1489)",
		"Entoku (1489–1492)",
		"Meiō (1492–1501)",
		"Bunki (1501–1504)",
		"Eishō (1504–1521)",
		"Taiei (1521–1528)",
		"Kyōroku (1528–1532)",
		"Tenbun (1532–1555)",
		"Kōji (1555–1558)",
		"Eiroku (1558–1570)",
		"Genki (1570–1573)",
		"Tenshō (1573–1592)",
		"Bunroku (1592–1596)",
		"Keichō (1596–1615)",
		"Genna (1615–1624)",
		"Kan’ei (1624–1644)",
		"Shōho (1644–1648)",
		"Keian (1648–1652)",
		"Jōō (1652–1655)",
		"Meireki (1655–1658)",
		"Manji (1658–1661)",
		"Kanbun (1661–1673)",
		"Enpō (1673–1681)",
		"Tenna (1681–1684)",
		"Jōkyō (1684–1688)",
		"Genroku (1688–1704)",
		"Hōei (1704–1711)",
		"Shōtoku (1711–1716)",
		"Kyōhō (1716–1736)",
		"Genbun (1736–1741)",
		"Kanpō (1741–1744)",
		"Enkyō (1744–1748)",
		"Kan’en (1748–1751)",
		"Hōreki (1751–1764)",
		"Meiwa (1764–1772)",
		"An’ei (1772–1781)",
		"Tenmei (1781–1789)",
		"Kansei (1789–1801)",
		"Kyōwa (1801–1804)",
		"Bunka (1804–1818)",
		"Bunsei (1818–1830)",
		"Tenpō (1830–1844)",
		"Kōka (1844–1848)",
		"Kaei (1848–1854)",
		"Ansei (1854–1860)",
		"Man’en (1860–1861)",
		"Bunkyū (1861–1864)",
		"Genji (1864–1865)",
		"Keiō (1865–1868)",
		"M",
		"T",
		"S",
		"H",
		"R"
	],
	"field-fri-narrow-relative+1": "next Friday",
	"quarters-standAlone-wide@localeAlias1559": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-weekOfMonth-narrow@localeAlias1588": {
		"bundle": "",
		"target": "field-weekOfMonth-short"
	},
	"field-weekOfMonth-narrow@localeAlias1589": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"days-standAlone-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"days-standAlone-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"dateFormatItem-Ehm": "E h:mm a",
	"dayPeriods@localeAlias1560": {
		"bundle": "gregorian",
		"target": "dayPeriods"
	},
	"dateTimeFormats-appendItem-Timezone": "{0} {1}",
	"field-wed-narrow-relative+-1": "last Wednesday",
	"field-minute-narrow-relative+0": "this minute",
	"field-tue-narrow@localeAlias1609": {
		"bundle": "",
		"target": "field-tue-short"
	},
	"days-format-wide": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-sat-short@localeAlias1620": {
		"bundle": "",
		"target": "field-sat"
	},
	"quarters-format-abbr@localeAlias1555": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-month-short-relative+0": "this month",
	"field-month-short-relative+1": "next month",
	"dateFormatItem-Ehms": "E h:mm:ss a",
	"field-tue-narrow@localeAlias1610": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-weekdayOfMonth-short@localeAlias1599": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-thu-relative+0": "this Thursday",
	"dayPeriods-format-wide-am": "AM",
	"field-thu-relative+1": "next Thursday",
	"dayPeriods-standAlone-narrow@localeAlias1564": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-narrow@localeAlias1565": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-fri-relative+0": "this Friday",
	"field-fri-relative+1": "next Friday",
	"field-quarter-relative+0": "this quarter",
	"field-thu-narrow-relative+-1": "last Thursday",
	"field-quarter-relative+1": "next quarter",
	"field-sun-short-relative+0": "this Sunday",
	"timeFormat-short": "HH:mm",
	"field-sun-short-relative+1": "next Sunday",
	"dateFormatItem-hms": "h:mm:ss a",
	"dateFormatItem-Md": "MM-dd",
	"field-week-narrow": "Week",
	"field-hour-relative+0": "this hour",
	"field-day-relative+-1": "yesterday",
	"field-mon-narrow-relative+-1": "last Monday",
	"field-minute-narrow": "Minute",
	"dateFormatItem-yyyyMMM": "G y MMM",
	"field-thu-short-relative+0": "this Thursday",
	"field-mon-relative+0": "this Monday",
	"field-thu-short-relative+1": "next Thursday",
	"field-mon-relative+1": "next Monday",
	"dateTimeFormats-appendItem-Era": "{1} {0}",
	"field-day-narrow-relative+0": "today",
	"field-era-short": "Era",
	"field-day-narrow-relative+1": "tomorrow",
	"field-sat-narrow-relative+0": "this Saturday",
	"timeFormat-long": "HH:mm:ss z",
	"field-sat-narrow-relative+1": "next Saturday",
	"field-day-short@localeAlias1590": {
		"bundle": "",
		"target": "field-day"
	},
	"field-week-narrow-relative+0": "this week",
	"field-week-narrow-relative+1": "next week",
	"field-hour-short-relative+0": "this hour",
	"field-wed-narrow-relative+0": "this Wednesday",
	"field-wed-narrow-relative+1": "next Wednesday",
	"field-mon-short@localeAlias1605": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-month": "Month",
	"months-standAlone-wide": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dateTimeFormats-appendItem-Second": "{0} ({2}: {1})",
	"field-weekday-narrow": "Day of the Week",
	"field-era-narrow@localeAlias1573": {
		"bundle": "",
		"target": "field-era-short"
	},
	"field-era-narrow@localeAlias1574": {
		"bundle": "",
		"target": "field-era"
	},
	"field-year-relative+0": "this year",
	"field-year-relative+1": "next year",
	"days-format-abbr@localeAlias1544": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-sun-short@localeAlias1602": {
		"bundle": "",
		"target": "field-sun"
	},
	"field-fri-narrow@localeAlias1618": {
		"bundle": "",
		"target": "field-fri-short"
	},
	"field-fri-narrow@localeAlias1619": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-tue-relative+0": "this Tuesday",
	"field-tue-relative+1": "next Tuesday",
	"field-minute-short-relative+0": "this minute",
	"dateFormatItem-hm": "h:mm a",
	"field-year-narrow": "Year",
	"quarters-format-narrow@localeAlias1556": {
		"bundle": "gregorian",
		"target": "quarters-standAlone-narrow"
	},
	"dateTimeFormats-appendItem-Day": "{0} ({2}: {1})",
	"field-tue-short-relative+0": "this Tuesday",
	"field-tue-short-relative+1": "next Tuesday",
	"dayPeriods-format-wide@localeAlias1562": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"dateTimeFormats-appendItem-Year": "{1} {0}",
	"dateTimeFormats-appendItem-Day-Of-Week": "{0} {1}",
	"field-tue-narrow-relative+0": "this Tuesday",
	"field-tue-narrow-relative+1": "next Tuesday",
	"dateTimeFormat-full": "{1} {0}",
	"dateFormatItem-E": "ccc",
	"dateFormatItem-EBhm": "E h:mm B",
	"dateFormatItem-H": "HH",
	"field-wed-relative+0": "this Wednesday",
	"field-wed-relative+1": "next Wednesday",
	"dateFormatItem-M": "L",
	"field-hour-narrow@localeAlias1627": {
		"bundle": "",
		"target": "field-hour-short"
	},
	"field-wed-short-relative+0": "this Wednesday",
	"field-hour-narrow@localeAlias1628": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-wed-short-relative+1": "next Wednesday",
	"field-fri-short-relative+0": "this Friday",
	"field-weekOfMonth-short": "Week Of Month",
	"field-fri-short-relative+1": "next Friday",
	"field-quarter-short-relative+-1": "last quarter",
	"field-year-short-relative+-1": "last year",
	"dateFormatItem-Bhm": "h:mm B",
	"dateTimeFormats-appendItem-Hour": "{0} ({2}: {1})",
	"dateTimeFormat-medium": "{1} {0}",
	"field-quarter-narrow-relative+-1": "last quarter",
	"dateFormatItem-d": "d",
	"dayPeriods-format-abbr-pm": "PM",
	"dateFormatItem-h": "h a",
	"quarters-standAlone-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-weekOfMonth-narrow": "Week Of Month",
	"field-day-narrow@localeAlias1591": {
		"bundle": "",
		"target": "field-day-short"
	},
	"field-day-narrow@localeAlias1592": {
		"bundle": "",
		"target": "field-day"
	},
	"dateFormatItem-yyyyQQQ": "G y QQQ",
	"dateFormatItem-yyyyMMMM": "G y MMMM",
	"dateFormatItem-y": "G y",
	"field-minute-relative+0": "this minute",
	"field-year-short-relative+0": "this year",
	"dateFormatItem-EBhms": "E h:mm:ss B",
	"field-year-short-relative+1": "next year",
	"field-weekday": "Day of the Week",
	"dayPeriods-format-narrow-pm": "PM",
	"dateTimeFormats-appendItem-Quarter": "{0} ({2}: {1})",
	"field-tue-narrow-relative+-1": "last Tuesday",
	"dayPeriods-standAlone-abbr@localeAlias1563": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-hour-short@localeAlias1626": {
		"bundle": "",
		"target": "field-hour"
	},
	"field-year-narrow-relative+-1": "last year",
	"dateFormatItem-yyyyMMMd": "G y MMM d",
	"field-sat-relative+-1": "last Saturday",
	"dayPeriods-standAlone-narrow-pm": "PM",
	"field-zone-narrow@localeAlias1636": {
		"bundle": "",
		"target": "field-zone-short"
	},
	"field-zone-narrow@localeAlias1637": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-mon-narrow-relative+0": "this Monday",
	"field-mon-narrow-relative+1": "next Monday",
	"quarters-standAlone-abbr@localeAlias1557": {
		"bundle": "gregorian",
		"target": "quarters-format-abbr"
	},
	"quarters-standAlone-abbr@localeAlias1558": {
		"bundle": "gregorian",
		"target": "quarters-format-wide"
	},
	"field-dayperiod-short@localeAlias1623": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"field-second": "Second",
	"field-year-relative+-1": "last year",
	"field-weekdayOfMonth-short": "Weekday Of Month",
	"dateFormat-short": "GGGGG y-MM-dd",
	"eraNames": [
		"Taika (645–650)",
		"Hakuchi (650–671)",
		"Hakuhō (672–686)",
		"Shuchō (686–701)",
		"Taihō (701–704)",
		"Keiun (704–708)",
		"Wadō (708–715)",
		"Reiki (715–717)",
		"Yōrō (717–724)",
		"Jinki (724–729)",
		"Tenpyō (729–749)",
		"Tenpyō-kampō (749–749)",
		"Tenpyō-shōhō (749–757)",
		"Tenpyō-hōji (757–765)",
		"Tenpyō-jingo (765–767)",
		"Jingo-keiun (767–770)",
		"Hōki (770–780)",
		"Ten-ō (781–782)",
		"Enryaku (782–806)",
		"Daidō (806–810)",
		"Kōnin (810–824)",
		"Tenchō (824–834)",
		"Jōwa (834–848)",
		"Kajō (848–851)",
		"Ninju (851–854)",
		"Saikō (854–857)",
		"Ten-an (857–859)",
		"Jōgan (859–877)",
		"Gangyō (877–885)",
		"Ninna (885–889)",
		"Kanpyō (889–898)",
		"Shōtai (898–901)",
		"Engi (901–923)",
		"Enchō (923–931)",
		"Jōhei (931–938)",
		"Tengyō (938–947)",
		"Tenryaku (947–957)",
		"Tentoku (957–961)",
		"Ōwa (961–964)",
		"Kōhō (964–968)",
		"Anna (968–970)",
		"Tenroku (970–973)",
		"Ten’en (973–976)",
		"Jōgen (976–978)",
		"Tengen (978–983)",
		"Eikan (983–985)",
		"Kanna (985–987)",
		"Eien (987–989)",
		"Eiso (989–990)",
		"Shōryaku (990–995)",
		"Chōtoku (995–999)",
		"Chōhō (999–1004)",
		"Kankō (1004–1012)",
		"Chōwa (1012–1017)",
		"Kannin (1017–1021)",
		"Jian (1021–1024)",
		"Manju (1024–1028)",
		"Chōgen (1028–1037)",
		"Chōryaku (1037–1040)",
		"Chōkyū (1040–1044)",
		"Kantoku (1044–1046)",
		"Eishō (1046–1053)",
		"Tengi (1053–1058)",
		"Kōhei (1058–1065)",
		"Jiryaku (1065–1069)",
		"Enkyū (1069–1074)",
		"Shōho (1074–1077)",
		"Shōryaku (1077–1081)",
		"Eihō (1081–1084)",
		"Ōtoku (1084–1087)",
		"Kanji (1087–1094)",
		"Kahō (1094–1096)",
		"Eichō (1096–1097)",
		"Jōtoku (1097–1099)",
		"Kōwa (1099–1104)",
		"Chōji (1104–1106)",
		"Kashō (1106–1108)",
		"Tennin (1108–1110)",
		"Ten-ei (1110–1113)",
		"Eikyū (1113–1118)",
		"Gen’ei (1118–1120)",
		"Hōan (1120–1124)",
		"Tenji (1124–1126)",
		"Daiji (1126–1131)",
		"Tenshō (1131–1132)",
		"Chōshō (1132–1135)",
		"Hōen (1135–1141)",
		"Eiji (1141–1142)",
		"Kōji (1142–1144)",
		"Ten’yō (1144–1145)",
		"Kyūan (1145–1151)",
		"Ninpei (1151–1154)",
		"Kyūju (1154–1156)",
		"Hōgen (1156–1159)",
		"Heiji (1159–1160)",
		"Eiryaku (1160–1161)",
		"Ōho (1161–1163)",
		"Chōkan (1163–1165)",
		"Eiman (1165–1166)",
		"Nin’an (1166–1169)",
		"Kaō (1169–1171)",
		"Shōan (1171–1175)",
		"Angen (1175–1177)",
		"Jishō (1177–1181)",
		"Yōwa (1181–1182)",
		"Juei (1182–1184)",
		"Genryaku (1184–1185)",
		"Bunji (1185–1190)",
		"Kenkyū (1190–1199)",
		"Shōji (1199–1201)",
		"Kennin (1201–1204)",
		"Genkyū (1204–1206)",
		"Ken’ei (1206–1207)",
		"Jōgen (1207–1211)",
		"Kenryaku (1211–1213)",
		"Kenpō (1213–1219)",
		"Jōkyū (1219–1222)",
		"Jōō (1222–1224)",
		"Gennin (1224–1225)",
		"Karoku (1225–1227)",
		"Antei (1227–1229)",
		"Kanki (1229–1232)",
		"Jōei (1232–1233)",
		"Tenpuku (1233–1234)",
		"Bunryaku (1234–1235)",
		"Katei (1235–1238)",
		"Ryakunin (1238–1239)",
		"En’ō (1239–1240)",
		"Ninji (1240–1243)",
		"Kangen (1243–1247)",
		"Hōji (1247–1249)",
		"Kenchō (1249–1256)",
		"Kōgen (1256–1257)",
		"Shōka (1257–1259)",
		"Shōgen (1259–1260)",
		"Bun’ō (1260–1261)",
		"Kōchō (1261–1264)",
		"Bun’ei (1264–1275)",
		"Kenji (1275–1278)",
		"Kōan (1278–1288)",
		"Shōō (1288–1293)",
		"Einin (1293–1299)",
		"Shōan (1299–1302)",
		"Kengen (1302–1303)",
		"Kagen (1303–1306)",
		"Tokuji (1306–1308)",
		"Enkyō (1308–1311)",
		"Ōchō (1311–1312)",
		"Shōwa (1312–1317)",
		"Bunpō (1317–1319)",
		"Genō (1319–1321)",
		"Genkō (1321–1324)",
		"Shōchū (1324–1326)",
		"Karyaku (1326–1329)",
		"Gentoku (1329–1331)",
		"Genkō (1331–1334)",
		"Kenmu (1334–1336)",
		"Engen (1336–1340)",
		"Kōkoku (1340–1346)",
		"Shōhei (1346–1370)",
		"Kentoku (1370–1372)",
		"Bunchū (1372–1375)",
		"Tenju (1375–1379)",
		"Kōryaku (1379–1381)",
		"Kōwa (1381–1384)",
		"Genchū (1384–1392)",
		"Meitoku (1384–1387)",
		"Kakei (1387–1389)",
		"Kōō (1389–1390)",
		"Meitoku (1390–1394)",
		"Ōei (1394–1428)",
		"Shōchō (1428–1429)",
		"Eikyō (1429–1441)",
		"Kakitsu (1441–1444)",
		"Bun’an (1444–1449)",
		"Hōtoku (1449–1452)",
		"Kyōtoku (1452–1455)",
		"Kōshō (1455–1457)",
		"Chōroku (1457–1460)",
		"Kanshō (1460–1466)",
		"Bunshō (1466–1467)",
		"Ōnin (1467–1469)",
		"Bunmei (1469–1487)",
		"Chōkyō (1487–1489)",
		"Entoku (1489–1492)",
		"Meiō (1492–1501)",
		"Bunki (1501–1504)",
		"Eishō (1504–1521)",
		"Taiei (1521–1528)",
		"Kyōroku (1528–1532)",
		"Tenbun (1532–1555)",
		"Kōji (1555–1558)",
		"Eiroku (1558–1570)",
		"Genki (1570–1573)",
		"Tenshō (1573–1592)",
		"Bunroku (1592–1596)",
		"Keichō (1596–1615)",
		"Genna (1615–1624)",
		"Kan’ei (1624–1644)",
		"Shōho (1644–1648)",
		"Keian (1648–1652)",
		"Jōō (1652–1655)",
		"Meireki (1655–1658)",
		"Manji (1658–1661)",
		"Kanbun (1661–1673)",
		"Enpō (1673–1681)",
		"Tenna (1681–1684)",
		"Jōkyō (1684–1688)",
		"Genroku (1688–1704)",
		"Hōei (1704–1711)",
		"Shōtoku (1711–1716)",
		"Kyōhō (1716–1736)",
		"Genbun (1736–1741)",
		"Kanpō (1741–1744)",
		"Enkyō (1744–1748)",
		"Kan’en (1748–1751)",
		"Hōreki (1751–1764)",
		"Meiwa (1764–1772)",
		"An’ei (1772–1781)",
		"Tenmei (1781–1789)",
		"Kansei (1789–1801)",
		"Kyōwa (1801–1804)",
		"Bunka (1804–1818)",
		"Bunsei (1818–1830)",
		"Tenpō (1830–1844)",
		"Kōka (1844–1848)",
		"Kaei (1848–1854)",
		"Ansei (1854–1860)",
		"Man’en (1860–1861)",
		"Bunkyū (1861–1864)",
		"Genji (1864–1865)",
		"Keiō (1865–1868)",
		"Meiji",
		"Taishō",
		"Shōwa",
		"Heisei",
		"Reiwa"
	],
	"field-second-short": "Second",
	"field-thu-short-relative+-1": "last Thursday",
	"field-zone": "Zone",
	"field-dayperiod-narrow": "Dayperiod",
	"field-sun-short-relative+-1": "last Sunday",
	"days-standAlone-wide@localeAlias1553": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormat@localeAlias1569": {
		"bundle": "generic",
		"target": "dateFormat"
	},
	"eraAbbr": [
		"Taika (645–650)",
		"Hakuchi (650–671)",
		"Hakuhō (672–686)",
		"Shuchō (686–701)",
		"Taihō (701–704)",
		"Keiun (704–708)",
		"Wadō (708–715)",
		"Reiki (715–717)",
		"Yōrō (717–724)",
		"Jinki (724–729)",
		"Tenpyō (729–749)",
		"Tenpyō-kampō (749–749)",
		"Tenpyō-shōhō (749–757)",
		"Tenpyō-hōji (757–765)",
		"Tenpyō-jingo (765–767)",
		"Jingo-keiun (767–770)",
		"Hōki (770–780)",
		"Ten-ō (781–782)",
		"Enryaku (782–806)",
		"Daidō (806–810)",
		"Kōnin (810–824)",
		"Tenchō (824–834)",
		"Jōwa (834–848)",
		"Kajō (848–851)",
		"Ninju (851–854)",
		"Saikō (854–857)",
		"Ten-an (857–859)",
		"Jōgan (859–877)",
		"Gangyō (877–885)",
		"Ninna (885–889)",
		"Kanpyō (889–898)",
		"Shōtai (898–901)",
		"Engi (901–923)",
		"Enchō (923–931)",
		"Jōhei (931–938)",
		"Tengyō (938–947)",
		"Tenryaku (947–957)",
		"Tentoku (957–961)",
		"Ōwa (961–964)",
		"Kōhō (964–968)",
		"Anna (968–970)",
		"Tenroku (970–973)",
		"Ten’en (973–976)",
		"Jōgen (976–978)",
		"Tengen (978–983)",
		"Eikan (983–985)",
		"Kanna (985–987)",
		"Eien (987–989)",
		"Eiso (989–990)",
		"Shōryaku (990–995)",
		"Chōtoku (995–999)",
		"Chōhō (999–1004)",
		"Kankō (1004–1012)",
		"Chōwa (1012–1017)",
		"Kannin (1017–1021)",
		"Jian (1021–1024)",
		"Manju (1024–1028)",
		"Chōgen (1028–1037)",
		"Chōryaku (1037–1040)",
		"Chōkyū (1040–1044)",
		"Kantoku (1044–1046)",
		"Eishō (1046–1053)",
		"Tengi (1053–1058)",
		"Kōhei (1058–1065)",
		"Jiryaku (1065–1069)",
		"Enkyū (1069–1074)",
		"Shōho (1074–1077)",
		"Shōryaku (1077–1081)",
		"Eihō (1081–1084)",
		"Ōtoku (1084–1087)",
		"Kanji (1087–1094)",
		"Kahō (1094–1096)",
		"Eichō (1096–1097)",
		"Jōtoku (1097–1099)",
		"Kōwa (1099–1104)",
		"Chōji (1104–1106)",
		"Kashō (1106–1108)",
		"Tennin (1108–1110)",
		"Ten-ei (1110–1113)",
		"Eikyū (1113–1118)",
		"Gen’ei (1118–1120)",
		"Hōan (1120–1124)",
		"Tenji (1124–1126)",
		"Daiji (1126–1131)",
		"Tenshō (1131–1132)",
		"Chōshō (1132–1135)",
		"Hōen (1135–1141)",
		"Eiji (1141–1142)",
		"Kōji (1142–1144)",
		"Ten’yō (1144–1145)",
		"Kyūan (1145–1151)",
		"Ninpei (1151–1154)",
		"Kyūju (1154–1156)",
		"Hōgen (1156–1159)",
		"Heiji (1159–1160)",
		"Eiryaku (1160–1161)",
		"Ōho (1161–1163)",
		"Chōkan (1163–1165)",
		"Eiman (1165–1166)",
		"Nin’an (1166–1169)",
		"Kaō (1169–1171)",
		"Shōan (1171–1175)",
		"Angen (1175–1177)",
		"Jishō (1177–1181)",
		"Yōwa (1181–1182)",
		"Juei (1182–1184)",
		"Genryaku (1184–1185)",
		"Bunji (1185–1190)",
		"Kenkyū (1190–1199)",
		"Shōji (1199–1201)",
		"Kennin (1201–1204)",
		"Genkyū (1204–1206)",
		"Ken’ei (1206–1207)",
		"Jōgen (1207–1211)",
		"Kenryaku (1211–1213)",
		"Kenpō (1213–1219)",
		"Jōkyū (1219–1222)",
		"Jōō (1222–1224)",
		"Gennin (1224–1225)",
		"Karoku (1225–1227)",
		"Antei (1227–1229)",
		"Kanki (1229–1232)",
		"Jōei (1232–1233)",
		"Tenpuku (1233–1234)",
		"Bunryaku (1234–1235)",
		"Katei (1235–1238)",
		"Ryakunin (1238–1239)",
		"En’ō (1239–1240)",
		"Ninji (1240–1243)",
		"Kangen (1243–1247)",
		"Hōji (1247–1249)",
		"Kenchō (1249–1256)",
		"Kōgen (1256–1257)",
		"Shōka (1257–1259)",
		"Shōgen (1259–1260)",
		"Bun’ō (1260–1261)",
		"Kōchō (1261–1264)",
		"Bun’ei (1264–1275)",
		"Kenji (1275–1278)",
		"Kōan (1278–1288)",
		"Shōō (1288–1293)",
		"Einin (1293–1299)",
		"Shōan (1299–1302)",
		"Kengen (1302–1303)",
		"Kagen (1303–1306)",
		"Tokuji (1306–1308)",
		"Enkyō (1308–1311)",
		"Ōchō (1311–1312)",
		"Shōwa (1312–1317)",
		"Bunpō (1317–1319)",
		"Genō (1319–1321)",
		"Genkō (1321–1324)",
		"Shōchū (1324–1326)",
		"Karyaku (1326–1329)",
		"Gentoku (1329–1331)",
		"Genkō (1331–1334)",
		"Kenmu (1334–1336)",
		"Engen (1336–1340)",
		"Kōkoku (1340–1346)",
		"Shōhei (1346–1370)",
		"Kentoku (1370–1372)",
		"Bunchū (1372–1375)",
		"Tenju (1375–1379)",
		"Kōryaku (1379–1381)",
		"Kōwa (1381–1384)",
		"Genchū (1384–1392)",
		"Meitoku (1384–1387)",
		"Kakei (1387–1389)",
		"Kōō (1389–1390)",
		"Meitoku (1390–1394)",
		"Ōei (1394–1428)",
		"Shōchō (1428–1429)",
		"Eikyō (1429–1441)",
		"Kakitsu (1441–1444)",
		"Bun’an (1444–1449)",
		"Hōtoku (1449–1452)",
		"Kyōtoku (1452–1455)",
		"Kōshō (1455–1457)",
		"Chōroku (1457–1460)",
		"Kanshō (1460–1466)",
		"Bunshō (1466–1467)",
		"Ōnin (1467–1469)",
		"Bunmei (1469–1487)",
		"Chōkyō (1487–1489)",
		"Entoku (1489–1492)",
		"Meiō (1492–1501)",
		"Bunki (1501–1504)",
		"Eishō (1504–1521)",
		"Taiei (1521–1528)",
		"Kyōroku (1528–1532)",
		"Tenbun (1532–1555)",
		"Kōji (1555–1558)",
		"Eiroku (1558–1570)",
		"Genki (1570–1573)",
		"Tenshō (1573–1592)",
		"Bunroku (1592–1596)",
		"Keichō (1596–1615)",
		"Genna (1615–1624)",
		"Kan’ei (1624–1644)",
		"Shōho (1644–1648)",
		"Keian (1648–1652)",
		"Jōō (1652–1655)",
		"Meireki (1655–1658)",
		"Manji (1658–1661)",
		"Kanbun (1661–1673)",
		"Enpō (1673–1681)",
		"Tenna (1681–1684)",
		"Jōkyō (1684–1688)",
		"Genroku (1688–1704)",
		"Hōei (1704–1711)",
		"Shōtoku (1711–1716)",
		"Kyōhō (1716–1736)",
		"Genbun (1736–1741)",
		"Kanpō (1741–1744)",
		"Enkyō (1744–1748)",
		"Kan’en (1748–1751)",
		"Hōreki (1751–1764)",
		"Meiwa (1764–1772)",
		"An’ei (1772–1781)",
		"Tenmei (1781–1789)",
		"Kansei (1789–1801)",
		"Kyōwa (1801–1804)",
		"Bunka (1804–1818)",
		"Bunsei (1818–1830)",
		"Tenpō (1830–1844)",
		"Kōka (1844–1848)",
		"Kaei (1848–1854)",
		"Ansei (1854–1860)",
		"Man’en (1860–1861)",
		"Bunkyū (1861–1864)",
		"Genji (1864–1865)",
		"Keiō (1865–1868)",
		"Meiji",
		"Taishō",
		"Shōwa",
		"Heisei",
		"Reiwa"
	],
	"field-week-short": "Week",
	"dayPeriods-standAlone-abbr-am": "AM",
	"dayPeriods-standAlone-wide-pm": "PM",
	"field-thu-narrow@localeAlias1615": {
		"bundle": "",
		"target": "field-thu-short"
	},
	"field-thu-narrow@localeAlias1616": {
		"bundle": "",
		"target": "field-thu"
	},
	"dateFormatItem-ms": "mm:ss",
	"field-day-relative+0": "today",
	"field-day-relative+1": "tomorrow",
	"field-weekday-narrow@localeAlias1597": {
		"bundle": "",
		"target": "field-weekday-short"
	},
	"field-weekday-narrow@localeAlias1598": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-year-short@localeAlias1575": {
		"bundle": "",
		"target": "field-year"
	},
	"field-sat-narrow@localeAlias1621": {
		"bundle": "",
		"target": "field-sat-short"
	},
	"field-sat-narrow@localeAlias1622": {
		"bundle": "",
		"target": "field-sat"
	},
	"field-day-short-relative+0": "today",
	"field-dayOfYear-short": "Day Of Year",
	"field-fri-short@localeAlias1617": {
		"bundle": "",
		"target": "field-fri"
	},
	"field-week-short@localeAlias1584": {
		"bundle": "",
		"target": "field-week"
	},
	"field-day-short-relative+1": "tomorrow",
	"dateFormat-long": "G y MMMM d",
	"field-sun-narrow-relative+-1": "last Sunday",
	"dayPeriods-format-narrow@localeAlias1561": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	},
	"field-second-relative+0": "now",
	"field-month-short@localeAlias1581": {
		"bundle": "",
		"target": "field-month"
	},
	"field-quarter-relative+-1": "last quarter",
	"field-dayperiod-narrow@localeAlias1624": {
		"bundle": "",
		"target": "field-dayperiod-short"
	},
	"field-dayperiod-narrow@localeAlias1625": {
		"bundle": "",
		"target": "field-dayperiod"
	},
	"months-standAlone-wide@localeAlias1542": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"days@localeAlias1543": {
		"bundle": "gregorian",
		"target": "days"
	},
	"quarters@localeAlias1554": {
		"bundle": "gregorian",
		"target": "quarters"
	},
	"quarters-format-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-wed-narrow@localeAlias1612": {
		"bundle": "",
		"target": "field-wed-short"
	},
	"field-wed-narrow@localeAlias1613": {
		"bundle": "",
		"target": "field-wed"
	},
	"field-week-relative+-1": "last week",
	"field-month-relative+-1": "last month",
	"months-format-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-year": "Year",
	"field-era": "Era",
	"days-standAlone-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"quarters-format-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-day-short-relative+-1": "yesterday",
	"dateFormatItem-GyMMM": "G y MMM",
	"timeFormat-full": "HH:mm:ss zzzz",
	"field-quarter-narrow@localeAlias1579": {
		"bundle": "",
		"target": "field-quarter-short"
	},
	"dateFormatItem-Bhms": "h:mm:ss B",
	"field-hour": "Hour",
	"field-dayOfYear-narrow": "Day Of Year",
	"eraNames@localeAlias1568": {
		"bundle": "japanese",
		"target": "eraAbbr"
	},
	"field-second-narrow-relative+0": "now",
	"field-quarter-narrow@localeAlias1580": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-quarter": "Quarter",
	"months@localeAlias1537": {
		"bundle": "gregorian",
		"target": "months"
	},
	"field-month-narrow-relative+0": "this month",
	"field-month-narrow-relative+1": "next month",
	"field-month-narrow@localeAlias1582": {
		"bundle": "",
		"target": "field-month-short"
	},
	"field-month-narrow@localeAlias1583": {
		"bundle": "",
		"target": "field-month"
	},
	"field-year-narrow@localeAlias1576": {
		"bundle": "",
		"target": "field-year-short"
	},
	"dateFormatItem-yyyy": "G y",
	"field-year-narrow@localeAlias1577": {
		"bundle": "",
		"target": "field-year"
	},
	"days-format-short@localeAlias1546": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-format-short@localeAlias1547": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateTimeFormats-appendItem-Minute": "{0} ({2}: {1})",
	"field-day": "Day",
	"field-dayOfYear-short@localeAlias1593": {
		"bundle": "",
		"target": "field-dayOfYear"
	},
	"field-mon-relative+-1": "last Monday",
	"field-dayOfYear": "Day Of Year",
	"dateFormat-medium": "G y MMM d",
	"dateTimeFormat-short": "{1} {0}",
	"dateFormatItem-GyMMMd": "G y MMM d",
	"dateFormatItem-MEd": "MM-dd, E",
	"field-tue-short-relative+-1": "last Tuesday",
	"field-year-short": "Year",
	"field-month-short": "Month",
	"field-wed-short@localeAlias1611": {
		"bundle": "",
		"target": "field-wed"
	},
	"dateFormatItem-MMMEd": "MMM d, E",
	"dateFormatItem-MMMd": "MMM d",
	"field-thu-short@localeAlias1614": {
		"bundle": "",
		"target": "field-thu"
	},
	"dateFormatItem-Bh": "h B",
	"months-format-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"dayPeriods-format-abbr-am": "AM",
	"months-format-narrow@localeAlias1539": {
		"bundle": "gregorian",
		"target": "months-standAlone-narrow"
	},
	"field-sat-relative+0": "this Saturday",
	"dayPeriods-format-wide-pm": "PM",
	"field-sat-relative+1": "next Saturday",
	"days-standAlone-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-zone-short": "Zone",
	"field-week-short-relative+0": "this week",
	"field-week-short-relative+1": "next week",
	"dateFormatItem-yyyyMMMEd": "G y MMM d, E",
	"dateTimeFormats-appendItem-Week": "{0} ({2}: {1})",
	"field-fri-short-relative+-1": "last Friday",
	"days-standAlone-abbr@localeAlias1548": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"field-month-narrow": "Month",
	"dayPeriods-format-narrow-am": "AM",
	"days-standAlone-abbr@localeAlias1549": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"field-month-narrow-relative+-1": "last month",
	"days-format-abbr": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"field-quarter-short@localeAlias1578": {
		"bundle": "",
		"target": "field-quarter"
	},
	"field-weekday-short": "Day of the Week",
	"field-weekday-short@localeAlias1596": {
		"bundle": "",
		"target": "field-weekday"
	},
	"field-day-narrow-relative+-1": "yesterday",
	"field-quarter-short": "Quarter",
	"days-format-short": [
		"Sun",
		"Mon",
		"Tue",
		"Wed",
		"Thu",
		"Fri",
		"Sat"
	],
	"months-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4",
		"5",
		"6",
		"7",
		"8",
		"9",
		"10",
		"11",
		"12"
	],
	"field-era-short@localeAlias1572": {
		"bundle": "",
		"target": "field-era"
	},
	"days-format-narrow": [
		"S",
		"M",
		"T",
		"W",
		"T",
		"F",
		"S"
	],
	"dateFormatItem-EHm": "E HH:mm",
	"field-quarter-narrow": "Quarter",
	"field-mon-short-relative+0": "this Monday",
	"field-mon-short-relative+1": "next Monday",
	"field-dayperiod-short": "Dayperiod",
	"months-format-abbr@localeAlias1538": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"dayPeriods-standAlone-narrow-am": "AM",
	"field-week-narrow-relative+-1": "last week",
	"field-thu-relative+-1": "last Thursday",
	"field-mon-short-relative+-1": "last Monday",
	"field-fri-narrow-relative+-1": "last Friday",
	"timeFormat-medium": "HH:mm:ss",
	"field-quarter-short-relative+0": "this quarter",
	"field-quarter-short-relative+1": "next quarter",
	"dateFormatItem-Ed": "d, E",
	"field-wed-relative+-1": "last Wednesday",
	"field-weekOfMonth": "Week Of Month",
	"field-weekdayOfMonth-narrow": "Weekday Of Month",
	"dayPeriods-standAlone-wide-am": "AM",
	"field-minute-short@localeAlias1629": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-fri-relative+-1": "last Friday",
	"field-weekdayOfMonth-narrow@localeAlias1600": {
		"bundle": "",
		"target": "field-weekdayOfMonth-short"
	},
	"field-weekOfMonth-short@localeAlias1587": {
		"bundle": "",
		"target": "field-weekOfMonth"
	},
	"field-weekdayOfMonth-narrow@localeAlias1601": {
		"bundle": "",
		"target": "field-weekdayOfMonth"
	},
	"field-minute": "Minute",
	"quarters-standAlone-narrow": [
		"1",
		"2",
		"3",
		"4"
	],
	"field-second-short-relative+0": "now",
	"quarters-format-wide": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-day-short": "Day",
	"field-dayperiod": "Dayperiod",
	"months-standAlone-abbr@localeAlias1540": {
		"bundle": "gregorian",
		"target": "months-format-abbr"
	},
	"field-hour-short": "Hour",
	"months-standAlone-abbr@localeAlias1541": {
		"bundle": "gregorian",
		"target": "months-format-wide"
	},
	"months-standAlone-abbr": [
		"M01",
		"M02",
		"M03",
		"M04",
		"M05",
		"M06",
		"M07",
		"M08",
		"M09",
		"M10",
		"M11",
		"M12"
	],
	"field-month-relative+0": "this month",
	"field-second-narrow": "Second",
	"field-month-relative+1": "next month",
	"dateFormat-full": "G y MMMM d, EEEE",
	"dateFormatItem-yyyyMEd": "GGGGG y-MM-dd, E",
	"field-era-narrow": "Era",
	"field-mon-narrow@localeAlias1606": {
		"bundle": "",
		"target": "field-mon-short"
	},
	"field-sat-short-relative+-1": "last Saturday",
	"field-mon-narrow@localeAlias1607": {
		"bundle": "",
		"target": "field-mon"
	},
	"field-sun-narrow@localeAlias1603": {
		"bundle": "",
		"target": "field-sun-short"
	},
	"field-week-short-relative+-1": "last week",
	"field-sun-narrow@localeAlias1604": {
		"bundle": "",
		"target": "field-sun"
	},
	"dateTimeFormat-long": "{1} {0}",
	"field-sun-relative+-1": "last Sunday",
	"field-wed-short-relative+-1": "last Wednesday",
	"dateFormatItem-yyyyQQQQ": "G y QQQQ",
	"field-weekdayOfMonth": "Weekday Of Month",
	"dateFormatItem-yyyyMd": "GGGGG y-MM-dd",
	"field-second-narrow@localeAlias1633": {
		"bundle": "",
		"target": "field-second-short"
	},
	"field-second-narrow@localeAlias1634": {
		"bundle": "",
		"target": "field-second"
	},
	"field-quarter-narrow-relative+0": "this quarter",
	"dateFormatItem-GyMMMEd": "G y MMM d, E",
	"field-quarter-narrow-relative+1": "next quarter",
	"field-sat-short-relative+0": "this Saturday",
	"field-sat-short-relative+1": "next Saturday",
	"field-hour-narrow": "Hour",
	"field-year-narrow-relative+0": "this year",
	"field-year-narrow-relative+1": "next year",
	"dateFormatItem-Gy": "G y",
	"field-tue-short@localeAlias1608": {
		"bundle": "",
		"target": "field-tue"
	},
	"field-zone-narrow": "Zone",
	"dateFormatItem-yyyyM": "GGGGG y-MM",
	"field-tue-relative+-1": "last Tuesday",
	"field-minute-short": "Minute",
	"days-standAlone-short@localeAlias1550": {
		"bundle": "gregorian",
		"target": "days-format-short"
	},
	"days-standAlone-short@localeAlias1551": {
		"bundle": "gregorian",
		"target": "days-format-abbr"
	},
	"days-standAlone-short@localeAlias1552": {
		"bundle": "gregorian",
		"target": "days-format-wide"
	},
	"dateFormatItem-Hm": "HH:mm",
	"field-week-relative+0": "this week",
	"field-week-relative+1": "next week",
	"dateFormatItem-MMM": "LLL",
	"field-sun-relative+0": "this Sunday",
	"field-sun-relative+1": "next Sunday",
	"field-zone-short@localeAlias1635": {
		"bundle": "",
		"target": "field-zone"
	},
	"field-week-narrow@localeAlias1585": {
		"bundle": "",
		"target": "field-week-short"
	},
	"field-week-narrow@localeAlias1586": {
		"bundle": "",
		"target": "field-week"
	},
	"days-format-narrow@localeAlias1545": {
		"bundle": "gregorian",
		"target": "days-standAlone-narrow"
	},
	"field-second-short@localeAlias1632": {
		"bundle": "",
		"target": "field-second"
	},
	"dateTime@localeAlias1571": {
		"bundle": "generic",
		"target": "dateTime"
	},
	"field-sat-narrow-relative+-1": "last Saturday",
	"dateTimeFormats-appendItem-Month": "{0} ({2}: {1})",
	"quarters-standAlone-abbr": [
		"Q1",
		"Q2",
		"Q3",
		"Q4"
	],
	"field-minute-narrow@localeAlias1630": {
		"bundle": "",
		"target": "field-minute-short"
	},
	"field-minute-narrow@localeAlias1631": {
		"bundle": "",
		"target": "field-minute"
	},
	"field-month-short-relative+-1": "last month",
	"dateFormatItem-EHms": "E HH:mm:ss",
	"timeFormat@localeAlias1570": {
		"bundle": "gregorian",
		"target": "timeFormat"
	},
	"dateFormatItem-MMMMd": "MMMM d",
	"field-week": "Week",
	"field-day-narrow": "Day",
	"field-hour-narrow-relative+0": "this hour",
	"dayPeriods-standAlone-wide@localeAlias1566": {
		"bundle": "gregorian",
		"target": "dayPeriods-standAlone-abbr"
	},
	"dayPeriods-standAlone-wide@localeAlias1567": {
		"bundle": "gregorian",
		"target": "dayPeriods-format-abbr"
	}
}
//end v1.x content
,
	"ar": true,
	"bs": true,
	"cs": true,
	"da": true,
	"de": true,
	"el": true,
	"en": true,
	"es": true,
	"fi": true,
	"fr": true,
	"he": true,
	"hr": true,
	"hu": true,
	"id": true,
	"it": true,
	"ja": true,
	"ko": true,
	"nb": true,
	"nl": true,
	"pl": true,
	"pt": true,
	"pt-pt": true,
	"ru": true,
	"sr": true,
	"sv": true,
	"th": true,
	"tr": true,
	"zh": true,
	"zh-hant": true
});